@@ -175,7 +175,7 @@ def push_json_to_s3(s3, json_obj, member_id, annotation_bucket, annotation_path,
 
 
 def process_sample(annotation_bucket, annotation_filename, annotation_path,
-                   samples_bucket, samples_path, member_id, s3, s3client):
+                   samples_bucket, samples_path, member_id):
     """
     Process a single member sample
     :param annotation_bucket: the annotation bucket
@@ -184,12 +184,16 @@ def process_sample(annotation_bucket, annotation_filename, annotation_path,
     :param samples_bucket: the samples bucket
     :param samples_path: the samples path
     :param member_id: the member id
-    :param s3: s3 object
-    :param s3client: s3client object
     :return:
     """
     import logging
 
+    import boto3
+
+    s3client = boto3.client('s3')
+    session = boto3.Session()
+    s3 = session.resource("s3")
+
     logging.info(f'Processing member {member_id}')
 
     samples = get_samples(s3client, member_id, samples_bucket=samples_bucket,
